@@ -11,10 +11,10 @@
 # 05.05.2022 Siegmar Müller vmkstationd3 begonnen
 # 01.11.2023 Siegmar Müller V 3.2 begonnen
 # 30.12.2023 Siegmar Müller Globale Daten explizit mit :: versehen
-# 24.01.2024 Siegmar Müller V 3.2.2 fertig
+# 17.01.2024 Siegmar Müller ping auf google nur mit ipv4
 #
 
-set ::VERSION "3.2.2"
+set ::VERSION "3.2.3"
 
 set ::dir [file dirname [info script]]
 if {[string equal -length 1 $::dir "."]} {
@@ -741,7 +741,7 @@ namespace eval ::wscomm {; #{{{
                     ::kernel::setStationsstatus WEBSERVICE 0
                 }
             } else {; # Keine Antwort auf ping 8.8.8.8
-                srvLog {inetcheck} Warn "Kein Internetzugang ($result)"
+                srvLog {inetcheck} Warn "Kein Internetzugang"
                 set internet_verfuegbar 0
                 ::kernel::setStationsstatus INET 0
             }
